@@ -30,7 +30,6 @@
 # (both user and password) from the API Details section from within your
 # account profile area:  https://d7networks.com/accounts/profile/
 
-import six
 import requests
 import base64
 from json import dumps
@@ -54,7 +53,7 @@ D7NETWORKS_HTTP_ERROR_MAP = {
 
 
 # Priorities
-class D7SMSPriority(object):
+class D7SMSPriority:
     """
     D7 Networks SMS Message Priority
     """
@@ -192,7 +191,7 @@ class NotifyD7Networks(NotifyBase):
 
         # Setup our source address (if defined)
         self.source = None \
-            if not isinstance(source, six.string_types) else source.strip()
+            if not isinstance(source, str) else source.strip()
 
         if not (self.user and self.password):
             msg = 'A D7 Networks user/pass was not provided.'
@@ -232,10 +231,10 @@ class NotifyD7Networks(NotifyBase):
 
         auth = '{user}:{password}'.format(
             user=self.user, password=self.password)
-        if six.PY3:
-            # Python 3's versio of b64encode() expects a byte array and not
-            # a string.  To accomodate this, we encode the content here
-            auth = auth.encode('utf-8')
+
+        # Python 3's versio of b64encode() expects a byte array and not
+        # a string.  To accommodate this, we encode the content here
+        auth = auth.encode('utf-8')
 
         # Prepare our headers
         headers = {
