@@ -32,7 +32,6 @@
 #           /blob/master/src/paho/mqtt/client.py
 import ssl
 import re
-import six
 from time import sleep
 from datetime import datetime
 from os.path import isfile
@@ -46,11 +45,6 @@ from ..AppriseLocale import gettext_lazy as _
 # Default our global support flag
 NOTIFY_MQTT_SUPPORT_ENABLED = False
 
-if six.PY2:
-    # handle Python v2.7 suport
-    class ConnectionError(Exception):
-        pass
-
 try:
     # 3rd party modules
     import paho.mqtt.client as mqtt
