@@ -28,7 +28,6 @@
 # - https://github.com/matrix-org/synapse/blob/master/docs/reverse_proxy.rst
 #
 import re
-import six
 import requests
 from markdown import markdown
 from json import dumps
@@ -67,7 +66,7 @@ IS_ROOM_ID = re.compile(
     r'(?P<home_server>[a-z0-9.-]+))?\s*$', re.I)
 
 
-class MatrixMessageType(object):
+class MatrixMessageType:
     """
     The Matrix Message types
     """
@@ -82,7 +81,7 @@ MATRIX_MESSAGE_TYPES = (
 )
 
 
-class MatrixWebhookMode(object):
+class MatrixWebhookMode:
     # Webhook Mode is disabled
     DISABLED = "off"
 
@@ -263,7 +262,7 @@ class NotifyMatrix(NotifyBase):
 
         # Setup our mode
         self.mode = self.template_args['mode']['default'] \
-            if not isinstance(mode, six.string_types) else mode.lower()
+            if not isinstance(mode, str) else mode.lower()
         if self.mode and self.mode not in MATRIX_WEBHOOK_MODES:
             msg = 'The mode specified ({}) is invalid.'.format(mode)
             self.logger.warning(msg)
@@ -271,7 +270,7 @@ class NotifyMatrix(NotifyBase):
 
         # Setup our message type
         self.msgtype = self.template_args['msgtype']['default'] \
-            if not isinstance(msgtype, six.string_types) else msgtype.lower()
+            if not isinstance(msgtype, str) else msgtype.lower()
         if self.msgtype and self.msgtype not in MATRIX_MESSAGE_TYPES:
             msg = 'The msgtype specified ({}) is invalid.'.format(msgtype)
             self.logger.warning(msg)
@@ -411,7 +410,7 @@ class NotifyMatrix(NotifyBase):
         """
 
         if not hasattr(self, '_re_slack_formatting_rules'):
-            # Prepare some one-time slack formating variables
+            # Prepare some one-time slack formatting variables
 
             self._re_slack_formatting_map = {
                 # New lines must become the string version
@@ -762,7 +761,7 @@ class NotifyMatrix(NotifyBase):
             # We can't join a room if we're not logged in
             return None
 
-        if not isinstance(room, six.string_types):
+        if not isinstance(room, str):
             # Not a supported string
             return None
 
@@ -850,7 +849,7 @@ class NotifyMatrix(NotifyBase):
             # We can't create a room if we're not logged in
             return None
 
-        if not isinstance(room, six.string_types):
+        if not isinstance(room, str):
             # Not a supported string
             return None
 
@@ -930,7 +929,7 @@ class NotifyMatrix(NotifyBase):
             # We can't get a room id if we're not logged in
             return None
 
-        if not isinstance(room, six.string_types):
+        if not isinstance(room, str):
             # Not a supported string
             return None
 
@@ -1109,20 +1108,20 @@ class NotifyMatrix(NotifyBase):
             #   - https://bugs.python.org/issue29288
             #
             # A ~similar~ issue can be identified here in the requests
-            # ticket system as unresolved and has provided work-arounds
+            # ticket system as unresolved and has provided workarounds
             #   - https://github.com/kennethreitz/requests/issues/3578
             pass
 
         except ImportError:  # pragma: no cover
             # The actual exception is `ModuleNotFoundError` however ImportError
-            # grants us backwards compatiblity with versions of Python older
+            # grants us backwards compatibility with versions of Python older
             # than v3.6
 
             # Python code that makes early calls to sys.exit() can cause
-            # the __del__() code to run. However in some newer versions of
+            # the __del__() code to run. However, in some newer versions of
             # Python, this causes the `sys` library to no longer be
             # available. The stack overflow also goes on to suggest that
-            # it's not wise to use the __del__() as a deconstructor
+            # it's not wise to use the __del__() as a destructor
             # which is the case here.
 
             # https://stackoverflow.com/questions/67218341/\
@@ -1134,7 +1133,7 @@ class NotifyMatrix(NotifyBase):
             #       /1481488/what-is-the-del-method-and-how-do-i-call-it
 
             # At this time it seems clean to try to log out (if we can)
-            # but not throw any unessisary exceptions (like this one) to
+            # but not throw any unnecessary exceptions (like this one) to
             # the end user if we don't have to.
             pass
 
