@@ -23,8 +23,6 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-# We use io because it allows us to test the open() call
-import io
 import base64
 import requests
 from json import loads
@@ -36,7 +34,7 @@ from ..utils import validate_regex
 from ..AppriseLocale import gettext_lazy as _
 
 
-class PushSaferSound(object):
+class PushSaferSound:
     """
     Defines all of the supported PushSafe sounds
     """
@@ -248,7 +246,7 @@ PUSHSAFER_SOUND_MAP = {
 
 
 # Priorities
-class PushSaferPriority(object):
+class PushSaferPriority:
     LOW = -2
     MODERATE = -1
     NORMAL = 0
@@ -282,7 +280,7 @@ DEFAULT_PRIORITY = "normal"
 
 
 # Vibrations
-class PushSaferVibration(object):
+class PushSaferVibration:
     """
     Defines the acceptable vibration settings for notification
     """
@@ -565,7 +563,7 @@ class NotifyPushSafer(NotifyBase):
                         attachment.url(privacy=True)))
 
                 try:
-                    with io.open(attachment.path, 'rb') as f:
+                    with open(attachment.path, 'rb') as f:
                         # Output must be in a DataURL format (that's what
                         # PushSafer calls it):
                         attachment = (
