@@ -785,7 +785,7 @@ class NotifyTwist(NotifyBase):
 
     def __del__(self):
         """
-        Deconstructor
+        Destructor
         """
         try:
             self.logout()
@@ -808,14 +808,14 @@ class NotifyTwist(NotifyBase):
 
         except ImportError:  # pragma: no cover
             # The actual exception is `ModuleNotFoundError` however ImportError
-            # grants us backwards compatiblity with versions of Python older
+            # grants us backwards compatibility with versions of Python older
             # than v3.6
 
             # Python code that makes early calls to sys.exit() can cause
-            # the __del__() code to run. However in some newer versions of
+            # the __del__() code to run. However, in some newer versions of
             # Python, this causes the `sys` library to no longer be
             # available. The stack overflow also goes on to suggest that
-            # it's not wise to use the __del__() as a deconstructor
+            # it's not wise to use the __del__() as a destructor
             # which is the case here.
 
             # https://stackoverflow.com/questions/67218341/\
@@ -827,6 +827,6 @@ class NotifyTwist(NotifyBase):
             #       /1481488/what-is-the-del-method-and-how-do-i-call-it
 
             # At this time it seems clean to try to log out (if we can)
-            # but not throw any unessisary exceptions (like this one) to
+            # but not throw any unnecessary exceptions (like this one) to
             # the end user if we don't have to.
             pass
