@@ -24,9 +24,9 @@
 # THE SOFTWARE.
 import re
 import os
-import six
 import requests
-import mock
+from unittest import mock
+
 from json import dumps
 from random import choice
 from string import ascii_uppercase as str_alpha
@@ -44,7 +44,7 @@ import logging
 logging.disable(logging.CRITICAL)
 
 
-class AppriseURLTester(object):
+class AppriseURLTester:
 
     # Some exception handling we'll use
     req_exceptions = (
@@ -144,7 +144,7 @@ class AppriseURLTester(object):
         # Allow us to force the server response text to be something other then
         # the defaults
         requests_response_text = meta.get('requests_response_text')
-        if not isinstance(requests_response_text, six.string_types):
+        if not isinstance(requests_response_text, str):
             # Convert to string
             requests_response_text = dumps(requests_response_text)
 
@@ -235,11 +235,11 @@ class AppriseURLTester(object):
 
             # We loaded okay; now lets make sure we can reverse
             # this url
-            assert isinstance(obj.url(), six.string_types) is True
+            assert isinstance(obj.url(), str) is True
 
             # Test url() with privacy=True
             assert isinstance(
-                obj.url(privacy=True), six.string_types) is True
+                obj.url(privacy=True), str) is True
 
             # Some Simple Invalid Instance Testing
             assert instance.parse_url(None) is None
@@ -292,7 +292,7 @@ class AppriseURLTester(object):
             print('%s AssertionError' % url)
             raise
 
-        # Tidy our object and allow any possible defined deconstructors to
+        # Tidy our object and allow any possible defined destructors to
         # be executed.
         del obj
 
@@ -339,7 +339,7 @@ class AppriseURLTester(object):
         # Allow us to force the server response text to be something other then
         # the defaults
         requests_response_text = meta.get('requests_response_text')
-        if not isinstance(requests_response_text, six.string_types):
+        if not isinstance(requests_response_text, str):
             # Convert to string
             requests_response_text = dumps(requests_response_text)
 
