@@ -25,7 +25,8 @@
 
 import re
 import time
-import mock
+from unittest import mock
+
 from os.path import dirname
 from os.path import join
 from apprise.attachment.AttachBase import AttachBase
