@@ -24,8 +24,8 @@
 # THE SOFTWARE.
 
 import re
-import six
-import mock
+from unittest import mock
+
 import requests
 import mimetypes
 from os.path import join
@@ -133,7 +133,7 @@ def test_attach_http(mock_get):
     # Temporary path
     path = join(TEST_VAR_DIR, 'apprise-test.gif')
 
-    class DummyResponse(object):
+    class DummyResponse:
         """
         A dummy response used to manage our object
         """
@@ -186,7 +186,7 @@ def test_attach_http(mock_get):
         'http://user:pass@localhost/apprise.gif?dl=1&cache=300')
     assert isinstance(results, dict)
     attachment = AttachHTTP(**results)
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
 
     # Test that our extended variables are passed along
     assert mock_get.call_count == 0
@@ -203,7 +203,7 @@ def test_attach_http(mock_get):
         'http://user:pass@localhost/apprise.gif?+key=value&cache=True')
     assert isinstance(results, dict)
     attachment = AttachHTTP(**results)
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
     # No mime-type and/or filename over-ride was specified, so therefore it
     # won't show up in the generated URL
     assert re.search(r'[?&]mime=', attachment.url()) is None
@@ -216,7 +216,7 @@ def test_attach_http(mock_get):
         'http://localhost:3000/noname.gif?name=usethis.jpg&mime=image/jpeg')
     assert isinstance(results, dict)
     attachment = AttachHTTP(**results)
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
     # both mime and name over-ridden
     assert re.search(r'[?&]mime=image%2Fjpeg', attachment.url())
     assert re.search(r'[?&]name=usethis.jpg', attachment.url())
@@ -250,7 +250,7 @@ def test_attach_http(mock_get):
     results = AttachHTTP.parse_url('http://localhost')
     assert isinstance(results, dict)
     attachment = AttachHTTP(**results)
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
     # No mime-type and/or filename over-ride was specified, so therefore it
     # won't show up in the generated URL
     assert re.search(r'[?&]mime=', attachment.url()) is None
@@ -272,7 +272,7 @@ def test_attach_http(mock_get):
     attachment = AttachHTTP(**results)
     # we can not download this attachment
     assert not attachment
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
     # No mime-type and/or filename over-ride was specified, so therefore it
     # won't show up in the generated URL
     assert re.search(r'[?&]mime=', attachment.url()) is None
@@ -291,7 +291,7 @@ def test_attach_http(mock_get):
     results = AttachHTTP.parse_url('http://localhost/no-length.gif')
     assert isinstance(results, dict)
     attachment = AttachHTTP(**results)
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
     # No mime-type and/or filename over-ride was specified, so therefore it
     # won't show up in the generated URL
     assert re.search(r'[?&]mime=', attachment.url()) is None
@@ -319,7 +319,7 @@ def test_attach_http(mock_get):
     results = AttachHTTP.parse_url('http://user@localhost/ignore-filename.gif')
     assert isinstance(results, dict)
     attachment = AttachHTTP(**results)
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
     # No mime-type and/or filename over-ride was specified, so therefore it
     # won't show up in the generated URL
     assert re.search(r'[?&]mime=', attachment.url()) is None
@@ -340,7 +340,7 @@ def test_attach_http(mock_get):
     attachment = AttachHTTP(**results)
     # we can not download this attachment
     assert not attachment
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
     # No mime-type and/or filename over-ride was specified, so therefore it
     # won't show up in the generated URL
     assert re.search(r'[?&]mime=', attachment.url()) is None
@@ -354,7 +354,7 @@ def test_attach_http(mock_get):
     results = AttachHTTP.parse_url('http://user@localhost')
     assert isinstance(results, dict)
     attachment = AttachHTTP(**results)
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
     # No mime-type and/or filename over-ride was specified, so therefore it
     # won't show up in the generated URL
     assert re.search(r'[?&]mime=', attachment.url()) is None
@@ -374,7 +374,7 @@ def test_attach_http(mock_get):
     results = AttachHTTP.parse_url('http://localhost/invalid-length.gif')
     assert isinstance(results, dict)
     attachment = AttachHTTP(**results)
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
     # No mime-type and/or filename over-ride was specified, so therefore it
     # won't show up in the generated URL
     assert re.search(r'[?&]mime=', attachment.url()) is None
@@ -392,7 +392,7 @@ def test_attach_http(mock_get):
     attachment = AttachHTTP(**results)
     # we can not download this attachment
     assert attachment
-    assert isinstance(attachment.url(), six.string_types) is True
+    assert isinstance(attachment.url(), str) is True
     # No mime-type and/or filename over-ride was specified, so therefore it
     # won't show up in the generated URL
     assert re.search(r'[?&]mime=', attachment.url()) is None
