@@ -23,7 +23,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 import pytest
-import mock
+from unittest import mock
+
 from helpers import AppriseURLTester
 from apprise import plugins
 from apprise import NotifyType
