@@ -23,8 +23,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 import os
-import sys
-import mock
+from unittest import mock
+
 import requests
 from apprise import plugins
 from helpers import AppriseURLTester
@@ -186,13 +186,6 @@ def test_plugin_custom_form_attachments(mock_post):
         body='body', title='title', notify_type=NotifyType.INFO,
         attach=attach) is False
 
-    # Get a appropriate "builtin" module name for pythons 2/3.
-    if sys.version_info.major >= 3:
-        builtin_open_function = 'builtins.open'
-
-    else:
-        builtin_open_function = '__builtin__.open'
-
     # Test Valid Attachment (load 3)
     path = (
         os.path.join(TEST_VAR_DIR, 'apprise-test.gif'),
@@ -204,14 +197,14 @@ def test_plugin_custom_form_attachments(mock_post):
     # Return our good configuration
     mock_post.side_effect = None
     mock_post.return_value = okay_response
-    with mock.patch(builtin_open_function, side_effect=OSError()):
+    with mock.patch('builtins.open', side_effect=OSError()):
         # We can't send the message we can't open the attachment for reading
         assert obj.notify(
             body='body', title='title', notify_type=NotifyType.INFO,
             attach=attach) is False
 
     # Fail on the 2nd attempt (but not the first)
-    with mock.patch(builtin_open_function,
+    with mock.patch('builtins.open',
                     side_effect=[None, OSError(), None]):
         # We can't send the message we can't open the attachment for reading
         assert obj.notify(
