@@ -23,7 +23,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 import json
-import mock
+from unittest import mock
+
 import requests
 from apprise import plugins
 from helpers import AppriseURLTester
