@@ -25,8 +25,8 @@
 
 import os
 import re
-import six
-import mock
+from unittest import mock
+
 import smtplib
 from email.header import decode_header
 
@@ -153,6 +153,20 @@ TEST_URLS = (
             'instance': plugins.NotifyEmail,
         },
     ),
+    (
+        # Test Reply To
+        'mailtos://user:pass@example.com?smtp=smtp.example.com'
+        '&name=l2g&reply=test@example.com,test2@example.com', {
+            'instance': plugins.NotifyEmail,
+        },
+    ),
+    (
+        # Test Reply To with bad email
+        'mailtos://user:pass@example.com?smtp=smtp.example.com'
+        '&name=l2g&reply=test@example.com,@', {
+            'instance': plugins.NotifyEmail,
+        },
+    ),
     # headers
     ('mailto://user:pass@localhost.localdomain'
         '?+X-Customer-Campaign-ID=Apprise', {
@@ -226,6 +240,9 @@ TEST_URLS = (
     ('mailto://user:pass@localhost/?cc=test2@,$@!/', {
         'instance': plugins.NotifyEmail,
     }),
+    ('mailto://user:pass@localhost/?reply=test2@,$@!/', {
+        'instance': plugins.NotifyEmail,
+    }),
 )
 
 
@@ -306,11 +323,11 @@ def test_plugin_email(mock_smtp, mock_smtpssl):
 
             if isinstance(obj, plugins.NotifyBase):
                 # We loaded okay; now lets make sure we can reverse this url
-                assert isinstance(obj.url(), six.string_types) is True
+                assert isinstance(obj.url(), str) is True
 
                 # Test url() with privacy=True
                 assert isinstance(
-                    obj.url(privacy=True), six.string_types) is True
+                    obj.url(privacy=True), str) is True
 
                 # Some Simple Invalid Instance Testing
                 assert instance.parse_url(None) is None
@@ -540,7 +557,7 @@ def test_plugin_email_smtplib_internationalization(mock_smtp):
         suppress_exceptions=False)
     assert isinstance(obj, plugins.NotifyEmail)
 
-    class SMTPMock(object):
+    class SMTPMock:
         def sendmail(self, *args, **kwargs):
             """
             over-ride sendmail calls so we can check our our
@@ -560,19 +577,11 @@ def test_plugin_email_smtplib_internationalization(mock_smtp):
             # Verify our output was correctly stored
             assert match_from.group('email') == 'user@gmail.com'
 
-            if six.PY2:  # Python 2.x (backwards compatible)
-                assert decode_header(match_from.group('name'))[0][0]\
-                    .decode('utf-8') == u'Например так'
+            assert decode_header(match_from.group('name'))[0][0]\
+                .decode('utf-8') == 'Например так'
 
-                assert decode_header(match_subject.group('subject'))[0][0]\
-                    .decode('utf-8') == u'دعونا نجعل العالم مكانا أفضل.'
-
-            else:  # Python 3+
-                assert decode_header(match_from.group('name'))[0][0]\
-                    .decode('utf-8') == 'Например так'
-
-                assert decode_header(match_subject.group('subject'))[0][0]\
-                    .decode('utf-8') == 'دعونا نجعل العالم مكانا أفضل.'
+            assert decode_header(match_subject.group('subject'))[0][0]\
+                .decode('utf-8') == 'دعونا نجعل العالم مكانا أفضل.'
 
         # Dummy Function
         def quit(self, *args, **kwargs):
@@ -781,7 +790,7 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert isinstance(_to, list)
     assert len(_to) == 1
     assert _to[0] == 'user2@yahoo.com'
-    assert _msg.endswith('test')
+    assert _msg.split('\n')[-3] == 'test'
 
     # Our URL port was over-ridden (on template) to use 444
     # We can verify that this was correctly saved
@@ -828,13 +837,15 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert isinstance(_to, list)
     assert len(_to) == 1
     assert _to[0] == 'user2@yahoo.com'
-    assert _msg.endswith('test')
+    assert _msg.split('\n')[-3] == 'test'
 
     assert obj.url().startswith(
         'mailtos://user:pass123@hotmail.com/user2%40yahoo.com')
     # Test that our template over-ride worked
     assert 'mode=ssl' in obj.url()
     assert 'smtp=override.com' in obj.url()
+    # No reply address specified
+    assert 'reply=' not in obj.url()
 
     mock_smtp.reset_mock()
     response.reset_mock()
@@ -847,22 +858,30 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     obj = Apprise.instantiate(results, suppress_exceptions=False)
     assert isinstance(obj, plugins.NotifyEmail) is True
     assert obj.smtp_host == 'smtp-mail.outlook.com'
+    # No entries in the reply_to
+    assert not obj.reply_to
 
     results = plugins.NotifyEmail.parse_url(
         'mailtos://user:pass123@outlook.com.au')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
     assert isinstance(obj, plugins.NotifyEmail) is True
     assert obj.smtp_host == 'smtp-mail.outlook.com'
+    # No entries in the reply_to
+    assert not obj.reply_to
 
     results = plugins.NotifyEmail.parse_url(
         'mailtos://user:pass123@live.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
     assert isinstance(obj, plugins.NotifyEmail) is True
+    # No entries in the reply_to
+    assert not obj.reply_to
 
     results = plugins.NotifyEmail.parse_url(
         'mailtos://user:pass123@hotmail.com')
     obj = Apprise.instantiate(results, suppress_exceptions=False)
     assert isinstance(obj, plugins.NotifyEmail) is True
+    # No entries in the reply_to
+    assert not obj.reply_to
 
     #
     # Test Port Over-Riding
@@ -878,6 +897,8 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert obj.port == 465
     assert obj.from_addr == 'abc@xyz.cn'
     assert obj.secure_mode == 'ssl'
+    # No entries in the reply_to
+    assert not obj.reply_to
 
     results = plugins.NotifyEmail.parse_url(
         "mailtos://abc:password@xyz.cn?"
@@ -890,3 +911,21 @@ def test_plugin_email_url_parsing(mock_smtp, mock_smtp_ssl):
     assert obj.port == 465
     assert obj.from_addr == 'abc@xyz.cn'
     assert obj.secure_mode == 'ssl'
+    # No entries in the reply_to
+    assert not obj.reply_to
+
+    #
+    # Test Reply-To Email
+    #
+    results = plugins.NotifyEmail.parse_url(
+        "mailtos://user:pass@example.com?reply=noreply@example.com")
+    obj = Apprise.instantiate(results, suppress_exceptions=False)
+    assert isinstance(obj, plugins.NotifyEmail) is True
+    # Verify our over-rides are in place
+    assert obj.smtp_host == 'example.com'
+    assert obj.from_addr == 'user@example.com'
+    assert obj.secure_mode == 'starttls'
+    assert obj.url().startswith(
+        'mailtos://user:pass@example.com')
+    # Test that our template over-ride worked
+    assert 'reply=noreply%40example.com' in obj.url()
