@@ -24,24 +24,15 @@
 # THE SOFTWARE.
 
 import re
-import six
 import pytest
-import mock
+from unittest import mock
+
 import sys
 import types
 import apprise
 from helpers import module_reload
+from importlib import reload
 
-try:
-    # Python v3.4+
-    from importlib import reload
-except ImportError:
-    try:
-        # Python v3.0-v3.3
-        from imp import reload
-    except ImportError:
-        # Python v2.7
-        pass
 
 # Disable logging for a cleaner testing output
 import logging
@@ -115,10 +106,6 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     reload(sys.modules['apprise.plugins.NotifyDBus'])
     mock_mainloop.qt.DBusQtMainLoop.side_effect = None
 
-    # Python v2.x
-    mock_mainloop.glib.DBusGMainLoop.return_value = True
-    mock_mainloop.glib.DBusGMainLoop.side_effect = ImportError()
-    # Python 3.x
     mock_mainloop.glib.NativeMainLoop.return_value = True
     mock_mainloop.glib.NativeMainLoop.side_effect = ImportError()
     sys.modules['dbus.mainloop.glib'] = mock_mainloop.glib
@@ -131,19 +118,19 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     # Create our instance (identify all supported types)
     obj = apprise.Apprise.instantiate('dbus://', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.url().startswith('dbus://_/')
     obj = apprise.Apprise.instantiate('kde://', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.url().startswith('kde://_/')
     obj = apprise.Apprise.instantiate('qt://', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.url().startswith('qt://_/')
     obj = apprise.Apprise.instantiate('glib://', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.url().startswith('glib://_/')
     obj.duration = 0
 
@@ -171,7 +158,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj = apprise.Apprise.instantiate(
         'dbus://_/?image=True', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.url().startswith('dbus://_/')
     assert re.search('image=yes', obj.url())
 
@@ -182,7 +169,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj = apprise.Apprise.instantiate(
         'dbus://_/?image=False', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.url().startswith('dbus://_/')
     assert re.search('image=no', obj.url())
 
@@ -194,7 +181,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj = apprise.Apprise.instantiate(
         'dbus://_/?priority=invalid', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -202,7 +189,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj = apprise.Apprise.instantiate(
         'dbus://_/?priority=high', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -210,7 +197,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj = apprise.Apprise.instantiate(
         'dbus://_/?priority=2', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -219,7 +206,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj = apprise.Apprise.instantiate(
         'dbus://_/?urgency=invalid', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -227,7 +214,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj = apprise.Apprise.instantiate(
         'dbus://_/?urgency=high', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -235,7 +222,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj = apprise.Apprise.instantiate(
         'dbus://_/?urgency=2', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -243,7 +230,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj = apprise.Apprise.instantiate(
         'dbus://_/?urgency=', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -252,7 +239,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj = apprise.Apprise.instantiate(
         'dbus://_/?x=5&y=5', suppress_exceptions=False)
     assert isinstance(obj, apprise.plugins.NotifyDBus) is True
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -375,7 +362,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj.duration = 0
 
     # Test url() call
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
 
     # Our notification succeeds even though the gi library was not loaded
     assert obj.notify(
@@ -404,7 +391,7 @@ def test_plugin_dbus_general(mock_mainloop, mock_byte, mock_bytearray,
     obj.duration = 0
 
     # Test url() call
-    assert isinstance(obj.url(), six.string_types) is True
+    assert isinstance(obj.url(), str) is True
 
     # Our notification succeeds even though the gi library was not loaded
     assert obj.notify(
