@@ -24,8 +24,8 @@
 # THE SOFTWARE.
 
 import sys
-import mock
-import six
+from unittest import mock
+
 import pytest
 import apprise
 from apprise.plugins.NotifyGrowl import GrowlPriority
@@ -271,11 +271,11 @@ def test_plugin_growl_general(mock_gntp):
 
             if isinstance(obj, apprise.plugins.NotifyBase):
                 # We loaded okay; now lets make sure we can reverse this url
-                assert isinstance(obj.url(), six.string_types) is True
+                assert isinstance(obj.url(), str) is True
 
                 # Test our privacy=True flag
                 assert isinstance(
-                    obj.url(privacy=True), six.string_types) is True
+                    obj.url(privacy=True), str) is True
 
                 # Instantiate the exact same object again using the URL from
                 # the one that was already created properly
