@@ -23,7 +23,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-import mock
+from unittest import mock
+
+import sys
 import json
 import requests
 import pytest
@@ -382,6 +384,8 @@ def test_plugin_msteams_templating(mock_post, tmpdir):
         == 'http://localhost'
 
 
+@pytest.mark.skipif(
+    hasattr(sys, "pypy_version_info"), reason="Does not work reliably on PyPy")
 @mock.patch('requests.post')
 def test_msteams_yaml_config(mock_post, tmpdir):
     """
