@@ -24,7 +24,8 @@
 # THE SOFTWARE.
 import os
 import json
-import mock
+from unittest import mock
+
 import requests
 from apprise import plugins
 import apprise
