@@ -24,7 +24,8 @@
 # THE SOFTWARE.
 
 import os
-import mock
+from unittest import mock
+
 import pytest
 import requests
 from json import dumps
