@@ -25,7 +25,8 @@
 import os
 import sys
 from json import loads
-import mock
+from unittest import mock
+
 import pytest
 import requests
 from apprise import plugins
