@@ -25,7 +25,8 @@
 
 import os
 import pytest
-import mock
+from unittest import mock
+
 import requests
 from json import dumps
 from apprise import plugins
